// Fill out your copyright notice in the Description page of Project Settings.

#pragma once

#include "CoreMinimal.h"
#include "BountyClass.h"
#include "SideBountyClass.h"
#include "MainBountyClass.generated.h"

/**
 * 
 */
UCLASS()
class ENDLESSVENDETTA_API AMainBountyClass : public ABountyClass
{
	GENERATED_BODY()

protected:
	UPROPERTY(EditDefaultsOnly, Category = "Bounty")
	TArray<TSubclassOf<ASideBountyClass>> SideBountiesToSpawn;
	
	// ---------------- Bounty Alterations ----------------
	UPROPERTY(EditDefaultsOnly, Category = "Bounty")
	FString CustomBountyAlteration_1_Description;

	UPROPERTY(EditDefaultsOnly, Category = "Bounty")
	int CustomBountyAlteration_1_Cost = 2;

	UPROPERTY(EditDefaultsOnly, Category = "Bounty")
	FString CustomBountyAlteration_2_Description;

	UPROPERTY(EditDefaultsOnly, Category = "Bounty")
	int CustomBountyAlteration_2_Cost = 2;

	UPROPERTY(EditDefaultsOnly, Category = "Bounty")
	FString CustomBountyAlteration_3_Description;

	UPROPERTY(EditDefaultsOnly, Category = "Bounty")
	int CustomBountyAlteration_3_Cost = 2;
	
	UPROPERTY(EditDefaultsOnly, Category = "Bounty")
	TArray<FTransform> AmmoDropSpawnTransforms;

	UPROPERTY(EditDefaultsOnly, Category = "Bounty")
	TSubclassOf<AActor> AmmoDropClass;

	UPROPERTY(EditDefaultsOnly, Category = "Bounty")
	TArray<FTransform> HealthDropSpawnTransforms;

	UPROPERTY(EditDefaultsOnly, Category = "Bounty")
	TSubclassOf<AActor> HealthDropClass;
	
	bool HasEnemyRadio = false;

public:
	TArray<TSubclassOf<ASideBountyClass>> GetSideBountiesToSpawn()
	{
		return SideBountiesToSpawn;
	}
	
	// ------------- Custom Bounty Alterations -------------
	UFUNCTION(BlueprintImplementableEvent, Category = "Bounty")
	void BuyCustomBountyAlteration_1();

	UFUNCTION(BlueprintImplementableEvent, Category = "Bounty")
	void BuyCustomBountyAlteration_2();
	
	UFUNCTION(BlueprintImplementableEvent, Category = "Bounty")
	void BuyCustomBountyAlteration_3();

	UFUNCTION(BlueprintCallable, Category = "Bounty")
	FString GetCustomBountyAlteration_1_Description()
	{
		return CustomBountyAlteration_1_Description;
	}
	
	UFUNCTION(BlueprintCallable, Category = "Bounty")
	FString GetCustomBountyAlteration_2_Description()
	{
		return CustomBountyAlteration_2_Description;
	}
	
	UFUNCTION(BlueprintCallable, Category = "Bounty")
	FString GetCustomBountyAlteration_3_Description()
	{
		return CustomBountyAlteration_3_Description;
	}

	UFUNCTION(BlueprintCallable, Category = "Bounty")
	int GetCustomBountyAlteration_1_Cost()
	{
		return CustomBountyAlteration_1_Cost;
	}

	UFUNCTION(BlueprintCallable, Category = "Bounty")
	int GetCustomBountyAlteration_2_Cost()
	{
		return CustomBountyAlteration_2_Cost;
	}

	UFUNCTION(BlueprintCallable, Category = "Bounty")
	int GetCustomBountyAlteration_3_Cost()
	{
		return CustomBountyAlteration_3_Cost;
	}
	// ------------- Simple Bounty Alterations	-------------

	void BuySpawnAmmoDrops();

	void BuySpawnHealthDrops();

	void BuyEnemyRadio()
	{
		HasEnemyRadio = true;
	}

	// Concerned Enemies will call this function, if true, play funny poop voice line and stop enemies from being concerned
	bool CheckIfHasEnemyRadio()
	{
		return HasEnemyRadio;
	};
	
};
